@@ -154,18 +154,19 @@ def processCustomTransactionOnChain(block,name,parameters:dict,pool:dict):
             'amountB': amountB
         }
     elif name == 'poolswap':
-        if 'tokenFrom' not in parameters or 'fromAmount' not in parameters or 'symbol' not in pool or 'commission' not in parameters or 'dexFeeInPct' not in parameters:
+        if 'fromAmount' not in parameters or 'isForward' not in parameters or 'commission' not in parameters or 'dexFeeInPct' not in parameters:
             # TODO: Raise Error
             return {
                 'error': 1,
                 'msg': 'tokenFrom and/or fromAmount and/or symbol and/or commission and/or dexFeeInPct missing'
             } 
-        (poolFrom,poolTo,swapped,dexFeeInAmount,dexFeeOutAmount) = chain.poolSwap(block,parameters['tokenFrom'],pool['symbol'],parameters['fromAmount'],pool['reserveA'],pool['reserveB'],parameters['commission'],parameters['dexFeeInPct'],parameters['dexFeeOutPct'])
+        (reserveAChange,reserveBChange,swapped,commissionAmount,dexFeeInAmount,dexFeeOutAmount) = chain.poolSwap(block,parameters['fromAmount'],parameters['isForward'],pool['reserveA'],pool['reserveB'],parameters['commission'],parameters['dexFeeInPct'],parameters['dexFeeOutPct'])
         return {
             'success': 1,
-            'reserveFrom': poolFrom,
-            'reserveTo': poolTo,
+            'reserveAChange': reserveAChange,
+            'reserveBChange': reserveBChange,
             'swapped': swapped,
+            'commissionAmount': commissionAmount,
             'dexFeeInAmount': dexFeeInAmount,
             'dexFeeOutAmount': dexFeeOutAmount
         }
