@@ -1,7 +1,8 @@
-# import utils.utils as utils
-# from utils.CustomTx import CustomTxType
-import defichainUtils.utils.utils as utils
-from defichainUtils.utils.CustomTx import CustomTxType
+from operator import truediv
+import utils.utils as utils
+from utils.CustomTx import CustomTxType
+# import defichainUtils.utils.utils as utils
+# from defichainUtils.utils.CustomTx import CustomTxType
 from dataclasses import asdict
 
 
@@ -230,7 +231,7 @@ def decodePaybackLoan(hex):
     return searchHex(variables,hex)
 def decodePaybackLoanV2(hex):
     variables = [
-        {'bytesCount': 32,'key': 'vaultId', 'type': 'hex','endian':'little'},
+        {'bytesCount': 32,'key': 'vaultId', 'type': 'hex','endian':'little', 'keepLeadingZeros': True},
         {'key': 'from', 'type': 'address','endian':None},
         {'key': 'tokens', 'type': [
             {'bytesCount': 1,'key': 'tokenId', 'type': int,'endian':None},
@@ -261,13 +262,13 @@ def decodeAnyAccountsToAccounts(hex):
     return searchHex(variables,hex)
 def decodeCloseVault(hex):
     variables = [
-        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little'},
+        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little', 'keepLeadingZeros': True},
         {'key': 'shareAddress', 'type': 'address','endian':None}
     ]
     return searchHex(variables,hex)
 def decodeUpdateVault(hex):
     variables = [
-        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little'},
+        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little', 'keepLeadingZeros': True},
         {'key': 'ownerAddress', 'type': 'address','endian':None},
         {'bytesCount': 1,'key': 'lengthLoanSchemeName', 'type': int,'endian':'little'},
         {'bytesCount': 'rest', 'key': 'loanScheme', 'type': str,'endian':None}
@@ -282,7 +283,7 @@ def decodeVault(hex):
     return searchHex(variables,hex)
 def decodeAuctionBid(hex):
     variables = [
-        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little'},
+        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little', 'keepLeadingZeros': True},
         {'bytesCount': 4,'key': 'index', 'type': int,'endian':'little'},
         {'key': 'address', 'type': 'address','endian':None},
         {'bytesCount': 1, 'key': 'tokenId', 'type': int,'endian':'little'},
@@ -291,7 +292,7 @@ def decodeAuctionBid(hex):
     return searchHex(variables,hex)
 def decodeWithdrawFromVault(hex):
     variables = [
-        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little'},
+        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little', 'keepLeadingZeros': True},
         {'key': 'to', 'type': 'address','endian':None},
         {'bytesCount': 1, 'key': 'tokenId', 'type': int,'endian':'little'},
         {'bytesCount': 8,'key': 'amount', 'type': int,'endian':'little'}
@@ -299,7 +300,7 @@ def decodeWithdrawFromVault(hex):
     return searchHex(variables,hex)
 def decodeDepositToVault(hex):
     variables = [
-        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little'},
+        {'bytesCount': 32, 'key': 'vaultId', 'type': 'hex', 'endian':'little', 'keepLeadingZeros': True},
         {'key': 'from', 'type': 'address','endian':None},
         {'bytesCount': 1, 'key': 'tokenId', 'type': int,'endian':'little'},
         {'bytesCount': 8,'key': 'amount', 'type': int,'endian':'little'}
@@ -389,10 +390,20 @@ def getValue(variable,hex):
             hex = hex[2*variable['bytesCount']:]
 
     # Handle Endian Transformation
+    hexZeros = ''
+    if 'keepLeadingZeros' in variable and variable['keepLeadingZeros'] and hexOfInterest[-2:] == '00':
+        counter = 0
+        while True:
+            search = hexOfInterest[- 2 * (counter + 1):] if counter == 0 else hexOfInterest[- 2 * (counter + 1):-2 * counter]
+            if search == '00':
+                hexZeros += '00'
+                counter += 1
+            else:
+                break
     if variable['endian'] == 'big':
-        hexOfInterest = utils.convert_hex(hexOfInterest,'big','little')
+        hexOfInterest = hexZeros + utils.convert_hex(hexOfInterest,'big','little')
     elif variable['endian'] == 'little':
-        hexOfInterest = utils.convert_hex(hexOfInterest,'little','big')
+        hexOfInterest = hexZeros + utils.convert_hex(hexOfInterest,'little','big')
 
     # Extract Value
     if variable['type'] == int:
